@@ -13,10 +13,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_iotdeviceadvisor.literals import Status, SuiteRunStatus
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -101,9 +99,7 @@ SuiteRunInformationTypeDef = TypedDict(
         "createdAt": datetime,
         "startedAt": datetime,
         "endAt": datetime,
-        "status": Literal[
-            "PASS", "FAIL", "CANCELED", "PENDING", "RUNNING", "PASS_WITH_WARNINGS", "ERROR"
-        ],
+        "status": SuiteRunStatus,
         "passed": int,
         "failed": int,
     },
@@ -124,9 +120,7 @@ TestCaseRunTypeDef = TypedDict(
         "testCaseRunId": str,
         "testCaseDefinitionId": str,
         "testCaseDefinitionName": str,
-        "status": Literal[
-            "PASS", "FAIL", "CANCELED", "PENDING", "RUNNING", "PASS_WITH_WARNINGS", "ERROR"
-        ],
+        "status": Status,
         "startTime": datetime,
         "endTime": datetime,
         "logUrl": str,
@@ -187,9 +181,7 @@ GetSuiteRunResponseTypeDef = TypedDict(
         "testResult": "TestResultTypeDef",
         "startTime": datetime,
         "endTime": datetime,
-        "status": Literal[
-            "PASS", "FAIL", "CANCELED", "PENDING", "RUNNING", "PASS_WITH_WARNINGS", "ERROR"
-        ],
+        "status": SuiteRunStatus,
         "errorReason": str,
         "tags": Dict[str, str],
     },
